@@ -18,11 +18,11 @@ Queue::DBI::Admin - Manage Queue::DBI queues.
 
 =head1 VERSION
 
-Version 2.3.1
+Version 2.4.0
 
 =cut
 
-our $VERSION = '2.3.1';
+our $VERSION = '2.4.0';
 
 
 =head1 SYNOPSIS
@@ -513,6 +513,28 @@ sub create_tables
 			)
 		) || croak 'Cannot execute SQL: ' . $database_handle->errstr();
 	}
+	elsif ( $database_type eq 'Pg' )
+	{
+		my $unique_index_name = $database_handle->quote_identifier(
+			'unq_' . $queues_table_name . '_name',
+		);
+		
+		$database_handle->do(
+			sprintf(
+				q|
+					CREATE TABLE %s
+					(
+						queue_id SERIAL,
+						name VARCHAR(255) NOT NULL,
+						PRIMARY KEY (queue_id),
+						CONSTRAINT %s UNIQUE (name)
+					)
+				|,
+				$quoted_queues_table_name,
+				$unique_index_name,
+			)
+		) || croak 'Cannot execute SQL: ' . $database_handle->errstr();
+	}
 	else
 	{
 		my $unique_index_name = $database_handle->quote_identifier(
@@ -557,6 +579,42 @@ sub create_tables
 			)
 		) || croak 'Cannot execute SQL: ' . $database_handle->errstr();
 	}
+	elsif ( $database_type eq 'Pg' )
+	{
+		$database_handle->do(
+			sprintf(
+				q|
+					CREATE TABLE %s
+					(
+						queue_element_id SERIAL,
+						queue_id INTEGER NOT NULL REFERENCES %s (queue_id),
+						data TEXT,
+						lock_time INTEGER DEFAULT NULL,
+						requeue_count SMALLINT DEFAULT 0,
+						created INTEGER NOT NULL DEFAULT 0,
+						PRIMARY KEY (queue_element_id)
+					)
+				|,
+				$quoted_queue_elements_table_name,
+				$quoted_queues_table_name,
+			)
+		) || croak 'Cannot execute SQL: ' . $database_handle->errstr();
+		
+		my $queue_id_index_name = $database_handle->quote_identifier(
+			'idx_' . $queue_elements_table_name . '_queue_id'
+		);
+		
+		$database_handle->do(
+			sprintf(
+				q|
+					CREATE INDEX %s
+					ON %s (queue_id)
+				|,
+				$queue_id_index_name,
+				$quoted_queue_elements_table_name,
+			)
+		) || croak 'Cannot execute SQL: ' . $database_handle->errstr();
+	}
 	else
 	{
 		my $queue_id_index_name = $database_handle->quote_identifier(
@@ -760,7 +818,7 @@ sub assert_database_type_supported
 	# Check the database type.
 	my $database_type = $self->get_database_type();
 	croak "This database type ($database_type) is not supported yet, please email the maintainer of the module for help"
-		if $database_type !~ m/^(?:SQLite|MySQL)$/i;
+		if $database_type !~ m/^(?:SQLite|MySQL|Pg)$/ix;
 	
 	return $database_type;
 }
